# SEC07-BP01: Identify the data within your workload

## Description

Inventory all data.

## Implementation Guidance

- Data discovery tools
- Data mapping documentation
- Sensitive data identification
- Data flow diagrams
- Regular data audits

## Risk Level

High - Unknown data can't be protected.
